StoryTreeEntry

Trait StoryTreeEntry 

pub trait StoryTreeEntry {
    // Required methods
    fn story_id(&self) -> &str;
    fn story_title(&self) -> &str;
}

Required Methods

fn story_id(&self) -> &str

Returns the route id for this story-like entry.

fn story_title(&self) -> &str

Returns the slash-delimited title path for this story-like entry.

Implementations on Foreign Types

Source

impl<T> StoryTreeEntry for &T
where T: StoryTreeEntry + ?Sized,

Source

fn story_id(&self) -> &str

Forwards the story id lookup through a shared reference.

Source

fn story_title(&self) -> &str

Forwards the story title lookup through a shared reference.

Implementors